# EcoDonut

Библиотека для расчёта экологического каркаса используемого на платформе ИДУ

## Как это работает

[Описание работы библиотеки](https://github.com/DDonnyy/EcoDonut/wiki/Описание-алгоритма-работы-библиотеки-Ecodonut-(RUS))

### Как интерпретировать результаты:

| name                     | type              | layer_impact | source         | color(optional) |
|--------------------------|-------------------|--------------|----------------|-----------------|
| ('Озеро', 'Свалка')      | ('water', 'dump') | -5           | (False, False) | #d93429         |
| ('Заправка', 'Дорога')   | ('water', 'road') | -3           | (False, True)  | #fdb96a         |
| ('Река', 'Зелёная зона') | ('water', 'dump') | 3            | (True, True)   | #bfe47a         |

В примере приведен срез результата пересечения некоторых слоёв влияния обьектов разного типа.

### Результат работы библиотеки на примере Ленинградской области
![image](https://github.com/DDonnyy/EcoDonut/assets/63115678/7c005ccd-74b8-4756-86f4-84f556f19215)

#### Базовые [примеры](./example) работы с библиотекой 

### Результат симуляции загрязнения воды от промышленных объектов по Санкт-Петербургу, находящихся рядом с реками.
![image](https://github.com/user-attachments/assets/a51e82a7-7e8d-433b-bb9d-2540b7230acd)
